# Blockbro-py

BlockBros-py makes it easier to interact with blockbros api
Contact me on discord for any help
## Installation

```bash
pip install blockbros-py
```

## License

[MIT](https://choosealicense.com/licenses/mit/)